Currency class

Constructors

Currency({required String symbol, required String code, required CurrencySymbolPosition symbolPosition})

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final
symbolPosition CurrencySymbolPosition
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited