CurrencyServiceImpl class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatWithCurrency(
double value, [Currency? curr, int numberOfDecimals = 2, bool ignoreDecimalIfZero = true]) → String -
override
-
formatWithCurrencyCode(
double value, [String currencyCode = 'EUR']) → String -
override
-
getCurrencyByCodeOrDefault(
[String? code]) → Currency -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited