DebounceServiceImpl class

Implemented types

Constructors

DebounceServiceImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debounce(void onExecute(), {Duration duration = const Duration(milliseconds: 1500), String tag = 'common-debouncer'}) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited