DeviceInfoService class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → DevicePlatform
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
info(
) → Map< String, dynamic> -
init(
) → Future< void> -
log(
[bool verbose = false]) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signature(
[String? prefix]) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited