FileService class abstract

Implementers

Constructors

FileService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFile({String? name, required String extension}) Future<FileInfo>
createFilePathAndName({String? name, required String extension, bool temporary = false}) Future<(String, String)>
getAppDocumentsDirectoryPath() Future<String>
getFileInfo(File file) FileInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String path) Future<void>
openOrThrow(String path) Future<void>
regenerateAbsolutePath(String absolutePath) Future<String>
toString() String
A string representation of this object.
inherited
writeToFile(Uint8List data) Future<File>

Operators

operator ==(Object other) bool
The equality operator.
inherited