VibrationServiceImpl class

Implemented types

Constructors

VibrationServiceImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error() Future<void>
override
heavy() Future<void>
override
light() Future<void>
override
medium() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rigid() Future<void>
override
selection() Future<void>
override
soft() Future<void>
override
success() Future<void>
override
toString() String
A string representation of this object.
inherited
warning() Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited