DevDurationX extension
- on
Properties
- positiveOrZero → Duration
-
Available on Duration?, provided by the DevDurationX extension
no setter
Methods
-
between(
Duration start, Duration end, [bool endInclusive = true]) → bool -
Available on Duration?, provided by the DevDurationX extension
-
format(
{bool hours = true, bool minutes = true, bool seconds = true, bool shrink = false, bool shrinkHours = true, bool shrinkMinutes = true, bool shrinkSeconds = true}) → String -
Available on Duration?, provided by the DevDurationX extension
-
increaseBy(
Duration duration) → Duration -
Available on Duration?, provided by the DevDurationX extension
Increases the current duration value by a duration parameter. -
prettyFormat(
) → String -
Available on Duration?, provided by the DevDurationX extension
-
scale(
Duration duration) → Duration -
Available on Duration?, provided by the DevDurationX extension
Decreases the current duration value by a duration parameter. Example: Current value: hours: 1, minutes: 30, seconds: 20, milliseconds: 500 duration: hours: 0, minutes: 10, seconds: 10, milliseconds: 100 Resulting value: hours: 1, minutes: 20, seconds: 10, milliseconds: 400 -
scaleByCoefficient(
[double coefficient = 1.0]) → Duration -
Available on Duration?, provided by the DevDurationX extension
Decreases the current duration value by a percentage of its value. Example: Current value: hours: 1, minutes: 30, seconds: 20, milliseconds: 500 coefficient: 0.5 Resulting value: hours: 0, minutes: 45, seconds: 10, milliseconds: 250 -
toFormattedString(
) → String -
Available on Duration?, provided by the DevDurationX extension
-
toJson(
) → String -
Available on Duration?, provided by the DevDurationX extension
Operators
-
operator /(
Duration other) → double -
Available on Duration?, provided by the DevDurationX extension