parseFullDuration method
Parses a full Duration value from a string.
The string must be in the format of HH:MM:SS.uS.
The micro seconds are padded with zeros to 6 digits for easier use.
Implementation
Duration? parseFullDuration(String key) {
try {
return parseValue(key, (x) => parseFullDurationValue(x));
} catch (e) {
debugPrint(e.toString());
return null;
}
}