FileInfo class
Constructors
- FileInfo({required String path, required File file, required String name, required String extension, required FileInfoType type, FileInfo? thumbnail})
- FileInfo.fromPath(String path)
-
factory
Properties
- extension ↔ String
-
getter/setter pair
- file ↔ File
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAudio → bool
-
no setter
- isImage → bool
-
no setter
- isOther → bool
-
no setter
- isVideo → bool
-
no setter
- name ↔ String
-
getter/setter pair
- nameWithExtension → String
-
no setter
- path ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ Future<
int> -
no setter
- thumbnail ↔ FileInfo?
-
getter/setter pair
- type ↔ FileInfoType
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited