FileServiceImpl class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createFile(
{String? name, required String extension}) → Future< FileInfo> -
override
-
createFilePathAndName(
{String? name, required String extension, bool temporary = false}) → Future< (String, String)> -
override
-
getAppDocumentsDirectoryPath(
[String? pathSufix]) → Future< String> -
override
-
getFileInfo(
File file) → FileInfo -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
String path) → Future< void> -
override
-
openOrThrow(
String path) → Future< void> -
override
-
regenerateAbsolutePath(
String absolutePath) → Future< String> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeToFile(
Uint8List data) → Future< File> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited